@@ -218,6 +218,7 @@ class ScriptJob(GenericJob):
         self.__name__ = "Script"
         self._script_path = None
         self.input = DataContainer(table_name="custom_dict")
+        self._enable_mpi4py = False
 
     @property
     def script_path(self):
@@ -240,13 +241,40 @@ class ScriptJob(GenericJob):
         if isinstance(path, str):
             self._script_path = self._get_abs_path(path)
             self.executable = self._executable_command(
-                working_directory=self.working_directory, script_path=self._script_path
+                working_directory=self.working_directory,
+                script_path=self._script_path,
+                enable_mpi4py=self._enable_mpi4py,
+                cores=self.server.cores,
             )
+            if self._enable_mpi4py:
+                self.executable._mpi = True
         else:
             raise TypeError(
                 "path should be a string, but ", path, " is a ", type(path), " instead."
             )
 
+    def enable_mpi4py(self):
+        if not self._enable_mpi4py:
+            self.executable = self._executable_command(
+                working_directory=self.working_directory,
+                script_path=self._script_path,
+                enable_mpi4py=True,
+                cores=self.server.cores,
+            )
+            self.executable._mpi = True
+        self._enable_mpi4py = True
+
+    def disable_mpi4py(self):
+        if self._enable_mpi4py:
+            self.executable = self._executable_command(
+                working_directory=self.working_directory,
+                script_path=self._script_path,
+                enable_mpi4py=False,
+                cores=self.server.cores,
+            )
+            self.executable._mpi = False
+        self._enable_mpi4py = False
+
     def validate_ready_to_run(self):
         if self.script_path is None:
             raise TypeError(
@@ -346,13 +374,17 @@ class ScriptJob(GenericJob):
         pass
 
     @staticmethod
-    def _executable_command(working_directory, script_path):
+    def _executable_command(
+        working_directory, script_path, enable_mpi4py=False, cores=1
+    ):
         """
         internal function to generate the executable command to either use jupyter or python
 
         Args:
             working_directory (str): working directory of the current job
             script_path (str): path to the script which should be executed in the working directory
+            enable_mpi4py (bool): flag to enable mpi4py
+            cores (int): number of cores to use
 
         Returns:
             str: executable command
@@ -364,8 +396,10 @@ class ScriptJob(GenericJob):
                 "jupyter nbconvert --ExecutePreprocessor.timeout=9999999 --to notebook --execute "
                 + path
             )
-        elif file_name[-3:] == ".py":
+        elif file_name[-3:] == ".py" and not enable_mpi4py:
             return "python " + path
+        elif file_name[-3:] == ".py" and enable_mpi4py:
+            return ["mpirun", "-np", str(cores), "python", path]
         else:
             raise ValueError("Filename not recognized: ", path)
 
